@@ -42,7 +42,6 @@
 
 #include "playlist.h"
 #include "collectionlist.h"
-#include "covermanager.h"
 #include "dynamicplaylist.h"
 #include "upcomingplaylist.h"
 #include "historyplaylist.h"
@@ -108,30 +107,19 @@ PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
         new KSelectAction( KIcon("view-choose"), i18n("View Modes"), ActionCollection::actions());
     ActionCollection::actions()->addAction("viewModeMenu", viewModeAction);
 
-    m_viewModes.append(new ViewMode(this));
-    m_viewModes.append(new CompactViewMode(this));
-    m_viewModes.append(new TreeViewMode(this));
-    // m_viewModes.append(new CoverManagerMode(this));
+    ViewMode* viewmode = new ViewMode(this);
+    m_viewModes.append(viewmode);
+    viewModeAction->addAction(KIcon("view-list-details"), viewmode->name());
 
-    QStringList modeNames;
+    CompactViewMode* compactviewmode = new CompactViewMode(this);
+    m_viewModes.append(compactviewmode);
+    viewModeAction->addAction(KIcon("view-list-text"), compactviewmode->name());
 
-    for(QList<ViewMode *>::Iterator it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
-        modeNames.append((*it)->name());
-
-    viewModeAction->setItems(modeNames);
-
-#ifdef __GNUC__
-#warning This needs to be ported to proper QActions
-#endif
-#if 0
-    QMenu *p = viewModeAction->menu();
-    p->changeItem(0, SmallIconSet("view-list-details"), modeNames[0]);
-    p->changeItem(1, SmallIconSet("view-list-text"), modeNames[1]);
-    p->changeItem(2, SmallIconSet("view-list-tree"), modeNames[2]);
-#endif
+    TreeViewMode* treeviewmode = new TreeViewMode(this);
+    m_viewModes.append(treeviewmode);
+    viewModeAction->addAction(KIcon("view-list-tree"), treeviewmode->name());
 
     CollectionList::initialize(this);
-    Cache::loadPlaylists(this);
 
     viewModeAction->setCurrentItem(m_viewModeIndex);
     m_viewModes[m_viewModeIndex]->setShown(true);
@@ -140,7 +128,7 @@ PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
     raise(CollectionList::instance());
 
     m_contextMenu->addAction( viewModeAction );
-    connect(viewModeAction, SIGNAL(activated(int)), this, SLOT(slotSetViewMode(int)));
+    connect(viewModeAction, SIGNAL(triggered(int)), this, SLOT(slotSetViewMode(int)));
 
     connect(this, SIGNAL(selectionChanged()),
             this, SLOT(slotPlaylistChanged()));
@@ -162,11 +150,15 @@ PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
     connect(CollectionList::instance(), SIGNAL(signalRemovedTag(const QString &, unsigned)),
             this, SLOT(slotRemoveItem(const QString &, unsigned)));
 
+    QTimer::singleShot(0, this, SLOT(slotLoadCachedPlaylists()));
     QTimer::singleShot(0, object(), SLOT(slotScanFolders()));
     enableDirWatch(true);
 
-    // Auto-save playlists after 10 minutes
-    QTimer::singleShot(600000, this, SLOT(slotSavePlaylists()));
+    // Auto-save playlists after they change.
+    m_savePlaylistTimer = new QTimer(this);
+    m_savePlaylistTimer->setInterval(3000); // 3 seconds with no change? -> commit
+    m_savePlaylistTimer->setSingleShot(true);
+    connect(m_savePlaylistTimer, SIGNAL(timeout()), SLOT(slotSavePlaylists()));
 
     m_showTimer = new QTimer(this);
     connect(m_showTimer, SIGNAL(timeout()), SLOT(slotShowDropTarget()));
@@ -245,6 +237,11 @@ void PlaylistBox::slotUnfreezePlaylists()
     setDynamicListsFrozen(false);
 }
 
+void PlaylistBox::slotPlaylistDataChanged()
+{
+    m_savePlaylistTimer->start(); // Restarts the timer if it's already running.
+}
+
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName)
 {
     setupPlaylist(playlist, iconName, 0);
@@ -319,7 +316,7 @@ void PlaylistBox::remove()
 
         if(remove == KMessageBox::Yes) {
             QStringList couldNotDelete;
-            for(QStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
+            for(QStringList::ConstIterator it = files.constBegin(); it != files.constEnd(); ++it) {
                 if(!QFile::remove(*it))
                     couldNotDelete.append(*it);
             }
@@ -344,7 +341,7 @@ void PlaylistBox::remove()
 
     PlaylistList removeQueue;
 
-    for(ItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
+    for(ItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
         if(*it != Item::collectionItem() &&
            (*it)->playlist() &&
            (!(*it)->playlist()->readOnly()))
@@ -366,7 +363,7 @@ void PlaylistBox::remove()
         setSingleItem(i);
     }
 
-    for(PlaylistList::ConstIterator it = removeQueue.begin(); it != removeQueue.end(); ++it) {
+    for(PlaylistList::ConstIterator it = removeQueue.constBegin(); it != removeQueue.constEnd(); ++it) {
         if(*it != upcomingPlaylist())
             delete *it;
         else {
@@ -388,7 +385,7 @@ void PlaylistBox::setDynamicListsFrozen(bool frozen)
 
 void PlaylistBox::slotSavePlaylists()
 {
-    kDebug(65432) << "Auto-saving playlists and covers.\n";
+    kDebug(65432) << "Auto-saving playlists.\n";
 
     PlaylistList l;
     CollectionList *collection = CollectionList::instance();
@@ -399,9 +396,6 @@ void PlaylistBox::slotSavePlaylists()
     }
 
     Cache::savePlaylists(l);
-    CoverManager::saveCovers();
-
-    QTimer::singleShot(600000, this, SLOT(slotSavePlaylists()));
 }
 
 void PlaylistBox::slotShowDropTarget()
@@ -431,11 +425,11 @@ void PlaylistBox::decode(const QMimeData *s, Item *item)
     if(!s || (item && item->playlist() && item->playlist()->readOnly()))
         return;
 
-    KUrl::List urls = KUrl::List::fromMimeData(s);
+    const KUrl::List urls = KUrl::List::fromMimeData(s);
 
     if(!urls.isEmpty()) {
         QStringList files;
-        for(KUrl::List::Iterator it = urls.begin(); it != urls.end(); ++it)
+        for(KUrl::List::ConstIterator it = urls.constBegin(); it != urls.constEnd(); ++it)
             files.append((*it).path());
 
         if(item) {
@@ -616,7 +610,7 @@ void PlaylistBox::slotPlaylistChanged()
     bool allowReload = false;
 
     PlaylistList playlists;
-    for(ItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
+    for(ItemList::ConstIterator it = items.constBegin(); it != items.constEnd(); ++it) {
 
         Playlist *p = (*it)->playlist();
         if(p) {
@@ -706,6 +700,12 @@ void PlaylistBox::setupUpcomingPlaylist()
     action<KToggleAction>("showUpcoming")->setChecked(enable);
 }
 
+
+void PlaylistBox::slotLoadCachedPlaylists()
+{
+    Cache::loadPlaylists(this);
+    emit startupComplete();
+}
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox::Item protected methods
 ////////////////////////////////////////////////////////////////////////////////
@@ -714,6 +714,7 @@ PlaylistBox::Item *PlaylistBox::Item::m_collectionItem = 0;
 
 PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l)
     : QObject(listBox), K3ListViewItem(listBox, 0, text),
+      PlaylistObserver(l),
       m_playlist(l), m_text(text), m_iconName(icon), m_sortedFirst(false)
 {
     init();
@@ -721,6 +722,7 @@ PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString
 
 PlaylistBox::Item::Item(Item *parent, const QString &icon, const QString &text, Playlist *l)
     : QObject(parent->listView()), K3ListViewItem(parent, text),
+    PlaylistObserver(l),
     m_playlist(l), m_text(text), m_iconName(icon), m_sortedFirst(false)
 {
     init();
@@ -782,6 +784,15 @@ void PlaylistBox::Item::slotSetName(const QString &name)
     }
 }
 
+void PlaylistBox::Item::updateCurrent()
+{
+}
+
+void PlaylistBox::Item::updateData()
+{
+    listView()->slotPlaylistDataChanged();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox::Item private methods
 ////////////////////////////////////////////////////////////////////////////////
