@@ -13,31 +13,31 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "tag.h"
+
 #include <kdebug.h>
 
-#include <qregexp.h>
-#include <qfile.h>
+#include <QFile>
 
 #include <taglib/tag.h>
-#include <taglib/mpegfile.h>
-#include <taglib/vorbisfile.h>
-#include <taglib/flacfile.h>
-#include <taglib/xiphcomment.h>
-#include <taglib/id3v2framefactory.h>
+#include <mpegfile.h>
+#include <vorbisfile.h>
+#include <flacfile.h>
+#include <xiphcomment.h>
+#include <id3v2framefactory.h>
 
 #if (TAGLIB_MAJOR_VERSION > 1) || \
       ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION >= 2))
-#include <taglib/oggflacfile.h>
+#include <oggflacfile.h>
 #define TAGLIB_1_2
 #endif
 #if (TAGLIB_MAJOR_VERSION > 1) || \
     ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION >= 3))
-#include <taglib/mpcfile.h>
+#include <mpcfile.h>
 #define TAGLIB_1_3
 #endif
 
 #include "cache.h"
-#include "tag.h"
 #include "mediafiles.h"
 #include "stringshare.h"
 
@@ -56,7 +56,7 @@ Tag::Tag(const QString &fileName) :
 {
     // using qDebug here since we want this to show up in non-debug builds as well
 
-    qDebug("Reading tag for %s", fileName.local8Bit().data());
+    qDebug("Reading tag for %s", fileName.toLocal8Bit().data());
 
     if(MediaFiles::isMP3(fileName)) {
         TagLib::MPEG::File file(QFile::encodeName(fileName).data());
@@ -71,7 +71,7 @@ Tag::Tag(const QString &fileName) :
     }
 #ifdef TAGLIB_1_3
     else if(MediaFiles::isMPC(fileName)) {
-        kdDebug(65432) << "Trying to resolve Musepack file" << endl;
+        kDebug(65432) << "Trying to resolve Musepack file";
         TagLib::MPC::File file(QFile::encodeName(fileName).data());
         if(file.isValid())
             setup(&file);
@@ -91,7 +91,7 @@ Tag::Tag(const QString &fileName) :
     }
 
     else {
-        kdError(65432) << "Couldn't resolve the mime type of \"" <<
+        kError(65432) << "Couldn't resolve the mime type of \"" <<
             fileName << "\" -- this shouldn't happen." << endl;
     }
 }
@@ -119,11 +119,11 @@ bool Tag::save()
         file = new TagLib::Vorbis::File(QFile::encodeName(m_fileName).data());
 
     if(file && file->isValid() && file->tag() && !file->readOnly()) {
-        file->tag()->setTitle(QStringToTString(m_title));
-        file->tag()->setArtist(QStringToTString(m_artist));
-        file->tag()->setAlbum(QStringToTString(m_album));
-        file->tag()->setGenre(QStringToTString(m_genre));
-        file->tag()->setComment(QStringToTString(m_comment));
+        file->tag()->setTitle(TagLib::String(m_title.toUtf8().data(), TagLib::String::UTF8));
+        file->tag()->setArtist(TagLib::String(m_artist.toUtf8().data(), TagLib::String::UTF8));
+        file->tag()->setAlbum(TagLib::String(m_album.toUtf8().data(), TagLib::String::UTF8));
+        file->tag()->setGenre(TagLib::String(m_genre.toUtf8().data(), TagLib::String::UTF8));
+        file->tag()->setComment(TagLib::String(m_comment.toUtf8().data(), TagLib::String::UTF8));
         file->tag()->setTrack(m_track);
         file->tag()->setYear(m_year);
 #ifdef TAGLIB_1_2
@@ -134,7 +134,7 @@ bool Tag::save()
 #endif
     }
     else {
-        kdError(65432) << "Couldn't save file." << endl;
+        kError(65432) << "Couldn't save file." << endl;
         result = false;
     }
 
@@ -146,10 +146,10 @@ CacheDataStream &Tag::read(CacheDataStream &s)
 {
     switch(s.cacheVersion()) {
     case 1: {
-        Q_INT32 track;
-        Q_INT32 year;
-        Q_INT32 bitrate;
-        Q_INT32 seconds;
+        qint32 track;
+        qint32 year;
+        qint32 bitrate;
+        qint32 seconds;
 
         s >> m_title
           >> m_artist
@@ -227,11 +227,11 @@ Tag::Tag(const QString &fileName, bool) :
 
 void Tag::setup(TagLib::File *file)
 {
-    m_title   = TStringToQString(file->tag()->title()).stripWhiteSpace();
-    m_artist  = TStringToQString(file->tag()->artist()).stripWhiteSpace();
-    m_album   = TStringToQString(file->tag()->album()).stripWhiteSpace();
-    m_genre   = TStringToQString(file->tag()->genre()).stripWhiteSpace();
-    m_comment = TStringToQString(file->tag()->comment()).stripWhiteSpace();
+    m_title   = TStringToQString(file->tag()->title()).trimmed();
+    m_artist  = TStringToQString(file->tag()->artist()).trimmed();
+    m_album   = TStringToQString(file->tag()->album()).trimmed();
+    m_genre   = TStringToQString(file->tag()->genre()).trimmed();
+    m_comment = TStringToQString(file->tag()->comment()).trimmed();
 
     m_track = file->tag()->track();
     m_year  = file->tag()->year();
@@ -245,8 +245,8 @@ void Tag::setup(TagLib::File *file)
     m_lengthString = QString::number(minutes) + (seconds >= 10 ? ":" : ":0") + QString::number(seconds);
 
     if(m_title.isEmpty()) {
-        int i = m_fileName.findRev('/');
-        int j = m_fileName.findRev('.');
+        int i = m_fileName.lastIndexOf('/');
+        int j = m_fileName.lastIndexOf('.');
         m_title = i > 0 ? m_fileName.mid(i + 1, j - i - 1) : m_fileName;
     }
 
@@ -263,12 +263,12 @@ QDataStream &operator<<(QDataStream &s, const Tag &t)
       << t.artist()
       << t.album()
       << t.genre()
-      << Q_INT32(t.track())
-      << Q_INT32(t.year())
+      << qint32(t.track())
+      << qint32(t.year())
       << t.comment()
-      << Q_INT32(t.bitrate())
+      << qint32(t.bitrate())
       << t.lengthString()
-      << Q_INT32(t.seconds());
+      << qint32(t.seconds());
 
     return s;
 }
@@ -277,3 +277,5 @@ CacheDataStream &operator>>(CacheDataStream &s, Tag &t)
 {
     return t.read(s);
 }
+
+// vim: set et sw=4 tw=0 sta:
