@@ -14,24 +14,22 @@
  ***************************************************************************/
 
 #include <config.h>
+#include <config-juk.h>
+#if HAVE_TUNEPIMP
 
-#if HAVE_MUSICBRAINZ
 
-#include <qlabel.h>
-
-#include <klistview.h>
+#include <k3listview.h>
 #include <klocale.h>
 
 #include "trackpickerdialog.h"
-#include "trackpickerdialogbase.h"
 
-#define NUMBER(x) (x == 0 ? QString::null : QString::number(x))
+#define NUMBER(x) (x == 0 ? QString::null : QString::number(x))	//krazy:exclude=nullstrassign for old broken gcc
 
-class TrackPickerItem : public KListViewItem
+class TrackPickerItem : public K3ListViewItem
 {
 public:
-    TrackPickerItem(KListView *parent, const KTRMResult &result) :
-        KListViewItem(parent, parent->lastChild(),
+    TrackPickerItem(K3ListView *parent, const KTRMResult &result) :
+        K3ListViewItem(parent, parent->lastChild(),
                       result.title(), result.artist(), result.album(),
                       NUMBER(result.track()), NUMBER(result.year())),
         m_result(result) {}
@@ -48,8 +46,14 @@ private:
 TrackPickerDialog::TrackPickerDialog(const QString &name,
                                      const KTRMResultList &results,
                                      QWidget *parent) :
-    KDialogBase(parent, name.latin1(), true, i18n("Internet Tag Guesser"), Ok | Cancel, Ok, true)
+    KDialog(parent)
 {
+    setObjectName(name.toAscii());
+    setModal(true);
+    setCaption(i18n("Internet Tag Guesser"));
+    setButtons(Ok | Cancel);
+    showButtonSeparator(true);
+
     m_base = new TrackPickerDialogBase(this);
     setMainWidget(m_base);
 
@@ -61,10 +65,10 @@ TrackPickerDialog::TrackPickerDialog(const QString &name,
 
     m_base->trackList->setSelected(m_base->trackList->firstChild(), true);
 
-    connect(m_base->trackList, SIGNAL(doubleClicked(QListViewItem *, const QPoint &, int)),
+    connect(m_base->trackList, SIGNAL(doubleClicked(Q3ListViewItem *, const QPoint &, int)),
             this, SLOT(accept()));
 
-    setMinimumWidth(kMax(400, width()));
+    setMinimumWidth(qMax(400, width()));
 }
 
 TrackPickerDialog::~TrackPickerDialog()
@@ -86,7 +90,7 @@ KTRMResult TrackPickerDialog::result() const
 
 int TrackPickerDialog::exec()
 {
-    int dialogCode = KDialogBase::exec();
+    int dialogCode = KDialog::exec();
 
     // Only return true if an item was selected.
 
@@ -98,4 +102,6 @@ int TrackPickerDialog::exec()
 
 #include "trackpickerdialog.moc"
 
-#endif // HAVE_MUSICBRAINZ
+#endif // HAVE_TUNEPIMP
+
+// vim: set et sw=4 tw=0 sta:
