@@ -17,16 +17,20 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /* This code is being #include'd from mixer.cpp */
 
 #include <config.h>
-
-#include <qstring.h>
+#include <config-alsa.h>
 
 #include "mixer_backend.h"
+#include "mixer.h"
+
+#include <QString>
+
+
 
 #if defined(sun) || defined(__sun__)
 #define SUN_MIXER
@@ -46,7 +50,7 @@
 #define OSS_MIXER
 #endif
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(_UNIXWARE) || defined(__DragonFly__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(_UNIXWARE)
 #define OSS_MIXER
 #endif
 
@@ -59,9 +63,6 @@
 #endif // hpux
 
 // PORTING: add #ifdef PLATFORM , commands , #endif, add your new mixer below
-#if defined(NAS_MIXER)
-#include "mixer_nas.cpp"
-#endif
 
 #if defined(SUN_MIXER)
 #include "mixer_sun.cpp"
@@ -78,36 +79,14 @@
 
 #if defined(OSS_MIXER)
 #include "mixer_oss.cpp"
-
-#if !defined(__NetBSD__) && !defined(__OpenBSD__)
-#include <sys/soundcard.h>
-#else
-#include <soundcard.h>
-#endif
-#if SOUND_VERSION >= 0x040000
-#define OSS4_MIXER
-#undef OSS_MIXER
-#endif
-
-#endif
-
-#if defined(OSS4_MIXER)
-#include "mixer_oss4.cpp"
 #endif
 
 #if defined(HPUX_MIXER)
 #include "mixer_hpux.cpp"
 #endif
 
-/*
-#else
-// We cannot handle this! I install a dummy mixer instead.
-#define NO_MIXER
-#include "mixer_none.cpp"
-#endif
-*/
 
-typedef Mixer_Backend *getMixerFunc( int device );
+typedef Mixer_Backend *getMixerFunc( Mixer* mixer, int device );
 typedef QString getDriverNameFunc( );
 
 struct MixerFactory {
@@ -117,10 +96,6 @@ struct MixerFactory {
 
 MixerFactory g_mixerFactories[] = {
 
-#if defined(NAS_MIXER)
-    { NAS_getMixer, 0 },
-#endif
-
 #if defined(SUN_MIXER)
     { SUN_getMixer, SUN_getDriverName },
 #endif
@@ -133,10 +108,6 @@ MixerFactory g_mixerFactories[] = {
     { ALSA_getMixer, ALSA_getDriverName },
 #endif
 
-#if defined(OSS4_MIXER)
-    { OSS4_getMixer, OSS4_getDriverName },
-#endif
-
 #if defined(OSS_MIXER)
     { OSS_getMixer, OSS_getDriverName },
 #endif
