@@ -16,35 +16,43 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef KMIXAPPLET_H
 #define KMIXAPPLET_H
 
 // Qt
-#include <qlayout.h>
-#include <qptrlist.h>
-#include <qwidget.h>
+#include <QLayout>
+#include <QWidget>
 
 // KDE
 #include <kaboutdata.h>
-#include <kdialogbase.h>
-#include <kpanelapplet.h>
+#include <kdialog.h>
+#include <k3panelapplet.h>
 
 //KMix
 #include "viewapplet.h"
+#include "ui_colorwidget.h"
 
 class Mixer;
-class ColorWidget;
 class KMixApplet;
 
+class ColorWidget : public QWidget, public Ui::ColorWidget
+{
+public:
+  ColorWidget( QWidget *parent=0 ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
 
-class AppletConfigDialog : public KDialogBase
+
+
+class AppletConfigDialog : public KDialog
 {
   Q_OBJECT
   public:
-   AppletConfigDialog( QWidget * parent=0, const char * name=0 );
+   explicit AppletConfigDialog( QWidget * parent=0, const char * name=0 );
    virtual ~AppletConfigDialog() {};
 
    void setActiveColors(const QColor& high, const QColor& low, const QColor& back);
@@ -67,13 +75,13 @@ class AppletConfigDialog : public KDialogBase
 };
 
 
-class KMixApplet : public KPanelApplet
+class KMixApplet : public K3PanelApplet
 {
    Q_OBJECT
 
 public:
-   KMixApplet( const QString& configFile, Type t = Normal,
-	       QWidget *parent = 0, const char *name = 0 );
+   KMixApplet( const QString& configFile, K3PanelApplet::Type t,
+	       QWidget *parent, const char *name );
    virtual ~KMixApplet();
 
    struct Colors {
@@ -105,11 +113,11 @@ protected:
    void loadConfig( KConfig *config, const QString &grp );
 
 private:
-   void positionChange(Position);
+   void positionChange(K3PanelApplet::Position);
    void setColors();
    void setColors( const Colors &color );
 
-   ViewApplet *m_mixerWidget;
+   ViewApplet *m_appletView;
    QPushButton *m_errorLabel;
    AppletConfigDialog *m_pref;
 
